#############################
Automatic generation for LIGO
#############################

The LIGO Detector Characterization group use the `gwsumm` package to generate
daily, weekly, and monthly summaries of the performance of the LIGO detectors.
These data generation runs are automatically completed using the HTCondor
high-throughput job scheduler.

Members of the LIGO Scientific Collaboration or the Virgo Collaboration
can view more details on the HTCondor configuration
`here <https://git.ligo.org/detchar/ligo-summary-pages>`_.
